# Welcome to expyta


[![image](https://img.shields.io/pypi/v/expyta.svg)](https://pypi.python.org/pypi/expyta)


**Expyta is a streamlined Python library that provides unified access to Taiwanese stock exchange APIs., designed for traders and developers.**


-   Free software: MIT License
-   Documentation: <https://ithomaslin.github.io/expyta>
    

## Features

-   TODO
